summaryrefslogtreecommitdiffstats
path: root/src/usr/devicefw
diff options
context:
space:
mode:
authorMarty Gloff <mgloff@us.ibm.com>2016-09-20 16:22:57 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2016-09-23 12:07:00 -0400
commit5e28eb679db54fa4f0040dd712b311d441ed6ca2 (patch)
tree856c0b093ede5d9aa8b36d14e5eb0dac96be9f72 /src/usr/devicefw
parent0e25c0479f1467b068fc1334295f15c4a1a2302e (diff)
downloadtalos-hostboot-5e28eb679db54fa4f0040dd712b311d441ed6ca2.tar.gz
talos-hostboot-5e28eb679db54fa4f0040dd712b311d441ed6ca2.zip
Changes for P9 SBE - Clean-up work from MRW
Finalize changes needed to correctly set MRW for SBE Update and SBE SEEPROMs. Check for receiving 0 as the Nest PLL Bucket ID. Change-Id: Ic6d47a8135ccc01f15d5d0d6a64736da31661090 RTC:161049 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/29995 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Andres A. Lugo-Reyes <aalugore@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/usr/devicefw')
-rw-r--r--src/usr/devicefw/associator.C11
1 files changed, 10 insertions, 1 deletions
diff --git a/src/usr/devicefw/associator.C b/src/usr/devicefw/associator.C
index 088deff90..a7bc7508e 100644
--- a/src/usr/devicefw/associator.C
+++ b/src/usr/devicefw/associator.C
@@ -298,7 +298,7 @@ namespace DeviceFW
// Check op type = i_opType registrations.
if (0 != ops[i_opType].offset)
{
// Check access type = WILDCARD registrations.
if(ops[i_opType].flag)
{
l_devRoute =
@@ -321,6 +321,15 @@ namespace DeviceFW
TRACDCOMP(g_traceBuffer, "findDeviceRoute did not find "
"i_opType=%d registration match", i_opType );
}
+ else
+ {
+ TRACDCOMP(g_traceBuffer, "findDeviceRoute, no op type %d "
+ "registrations, iv_routeMap=%d, routeMap=%p, "
+ "i_accessType=%d, offset=%d, ops=%p, "
+ "&ops[i_opType]=%p",
+ i_opType, iv_routeMap, routeMap, i_accessType,
+ routeMap[i_accessType].offset, ops, &ops[i_opType] );
+ }
} while(0);
return l_devRoute;
OpenPOWER on IntegriCloud
@@ -298,7 +298,7 @@ namespace DeviceFW
if (0 != ops[i_opType].offset)
{
- // Check access type = WILDCARD registrations.
+ // Check access type = i_opType registrations.
if(ops[i_opType].flag)
{